@@ -235,6 +235,21 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
   TE <- x$TE[o]
   seTE <- x$seTE[o]
   #
+  if (!is.null(x$cluster))
+    cluster <- x$cluster[o]
+  else
+    cluster <- NULL
+  #
+  if (!is.null(x$weights.common))
+    weights.common <- x$weights.common[o]
+  else
+    weights.common <- NULL
+  #
+  if (!is.null(x$weights.random))
+    weights.random <- x$weights.random[o]
+  else
+    weights.random <- NULL
+  #
   incr.e <- x$incr.e[o]
   incr.c <- x$incr.c[o]
   #
@@ -345,7 +360,12 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
       m <- metabin(event.e[sel], n.e[sel], event.c[sel], n.c[sel],
                    ##
                    exclude = exclude[sel],
-                   ##
+                   #
+                   cluster = cluster[sel], rho = x$rho,
+                   #
+                   weights.common = weights.common[sel],
+                   weights.random = weights.random[sel],
+                   #
                    method = x$method, sm = x$sm,
                    #
                    incr.e = incr.e[sel], incr.c = incr.c[sel],
@@ -358,6 +378,7 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
                    level.ma = x$level.ma,
+                   method.common.ci = x$method.common.ci,
                    method.random.ci = x$method.random.ci,
                    adhoc.hakn.ci = x$adhoc.hakn.ci,
                    #
@@ -375,7 +396,12 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
                     n.c[sel], mean.c[sel], sd.c[sel],
                     ##
                     exclude = exclude[sel],
-                    ##
+                    #
+                    cluster = cluster[sel], rho = x$rho,
+                    #
+                    weights.common = weights.common[sel],
+                    weights.random = weights.random[sel],
+                    #
                     sm = x$sm,
                     pooledvar = replaceNA(x$pooledvar, gs("pooledvar")),
                     ##
@@ -383,6 +409,7 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
                     level.ma = x$level.ma,
+                    method.common.ci = x$method.common.ci,
                     method.random.ci = x$method.random.ci,
                     adhoc.hakn.ci = x$adhoc.hakn.ci,
                     #
@@ -399,13 +426,19 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
       m <- metacor(cor[sel], n[sel],
                    ##
                    exclude = exclude[sel],
-                   ##
+                   #
+                   cluster = cluster[sel], rho = x$rho,
+                   #
+                   weights.common = weights.common[sel],
+                   weights.random = weights.random[sel],
+                   #
                    sm = x$sm, null.effect = x$null.effect,
                    ##
                    method.tau = x$method.tau,
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
                    level.ma = x$level.ma,
+                   method.common.ci = x$method.common.ci,
                    method.random.ci = x$method.random.ci,
                    adhoc.hakn.ci = x$adhoc.hakn.ci,
                    #
@@ -421,13 +454,19 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
       m <- metagen(TE[sel], seTE[sel],
                    ##
                    exclude = exclude[sel],
-                   ##
+                   #
+                   cluster = cluster[sel], rho = x$rho,
+                   #
+                   weights.common = weights.common[sel],
+                   weights.random = weights.random[sel],
+                   #
                    sm = x$sm, null.effect = x$null.effect,
                    ##
                    method.tau = x$method.tau,
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
                    level.ma = x$level.ma,
+                   method.common.ci = x$method.common.ci,
                    method.random.ci = x$method.random.ci,
                    adhoc.hakn.ci = x$adhoc.hakn.ci,
                    #
@@ -445,7 +484,12 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
                    event.c[sel], time.c[sel],
                    ##
                    exclude = exclude[sel],
-                   ##
+                   #
+                   cluster = cluster[sel], rho = x$rho,
+                   #
+                   weights.common = weights.common[sel],
+                   weights.random = weights.random[sel],
+                   #
                    method = x$method, sm = x$sm,
                    #
                    incr.e = incr.e[sel], incr.c = incr.c[sel],
@@ -456,6 +500,7 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
                    level.ma = x$level.ma,
+                   method.common.ci = x$method.common.ci,
                    method.random.ci = x$method.random.ci,
                    adhoc.hakn.ci = x$adhoc.hakn.ci,
                    #
@@ -472,13 +517,19 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
       m <- metamean(n[sel], mean[sel], sd[sel],
                     ##
                     exclude = exclude[sel],
-                    ##
+                    #
+                    cluster = cluster[sel], rho = x$rho,
+                    #
+                    weights.common = weights.common[sel],
+                    weights.random = weights.random[sel],
+                    #
                     sm = x$sm, null.effect = x$null.effect,
                     ##
                     method.tau = x$method.tau,
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
                     level.ma = x$level.ma,
+                    method.common.ci = x$method.common.ci,
                     method.random.ci = x$method.random.ci,
                     adhoc.hakn.ci = x$adhoc.hakn.ci,
                     #
@@ -495,7 +546,12 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
       m <- metaprop(event[sel], n[sel],
                     ##
                     exclude = exclude[sel],
-                    ##
+                    #
+                    cluster = cluster[sel], rho = x$rho,
+                    #
+                    weights.common = weights.common[sel],
+                    weights.random = weights.random[sel],
+                    #
                     method = x$method, sm = x$sm, null.effect = x$null.effect,
                     ##
                     incr = incr.i, method.incr = x$method.incr,
@@ -505,6 +561,7 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
                     level.ma = x$level.ma,
+                    method.common.ci = x$method.common.ci,
                     method.random.ci = x$method.random.ci,
                     adhoc.hakn.ci = x$adhoc.hakn.ci,
                     #
@@ -521,7 +578,12 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
       m <- metarate(event[sel], time[sel],
                     ##
                     exclude = exclude[sel],
-                    ##
+                    #
+                    cluster = cluster[sel], rho = x$rho,
+                    #
+                    weights.common = weights.common[sel],
+                    weights.random = weights.random[sel],
+                    #
                     method = x$method, sm = x$sm, null.effect = x$null.effect,
                     ##
                     incr = incr.i, method.incr = x$method.incr,
@@ -530,6 +592,7 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
                     level.ma = x$level.ma,
+                    method.common.ci = x$method.common.ci,
                     method.random.ci = x$method.random.ci,
                     adhoc.hakn.ci = x$adhoc.hakn.ci,
                     #
@@ -842,6 +905,7 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
               method = x$method,
               method.random = x$method.random,
               #
+              method.common.ci = x$method.common.ci,
               method.random.ci = x$method.random.ci,
               adhoc.hakn.ci = x$adhoc.hakn.ci,
               #
@@ -920,6 +984,16 @@ metacum.meta <- function(x, pooled, sortvar, prediction, overall = x$overall,
               ##
               call = match.call())
   #
+  if (!is.null(weights.common) & pooled == "common") {
+    res$weights.common <- TRUE
+    res$weights.random <- FALSE
+  }
+  #
+  if (!is.null(weights.random) & pooled == "random") {
+    res$weights.common <- FALSE
+    res$weights.random <- TRUE
+  }
+  #
   if (run_cidprop) {
     res$cid.below.null <- pp$cid.below.null
     res$cid.above.null <- pp$cid.above.null
