@@ -203,6 +203,7 @@ smd2or <- function(smd, se.smd, studlab,
                      ##
                      method.tau = mdat$method.tau,
                      method.tau.ci = mdat$method.tau.ci,
+                     level.hetstat = mdat$level.hetstat,
                      tau.common = mdat$tau.common,
                      detail.tau = mdat$detail.tau,
                      ##
@@ -220,10 +221,13 @@ smd2or <- function(smd, se.smd, studlab,
                      ##
                      title = mdat$title, complab = mdat$complab,
                      outclab = mdat$outclab,
+                     #
                      label.e = mdat$label.e, label.c = mdat$label.c,
                      label.left = mdat$label.left,
                      label.right = mdat$label.right,
-                     ##
+                     col.label.left = mdat$col.label.left,
+                     col.label.right = mdat$col.label.right,
+                     #
                      control = mdat$control)
     else
       res <- metagen(lnOR, selnOR, studlab = mdat$studlab,
@@ -249,6 +253,7 @@ smd2or <- function(smd, se.smd, studlab,
                      ##
                      method.tau = mdat$method.tau,
                      method.tau.ci = mdat$method.tau.ci,
+                     level.hetstat = mdat$level.hetstat,
                      tau.common = mdat$tau.common,
                      detail.tau = mdat$detail.tau,
                      ##
@@ -266,10 +271,13 @@ smd2or <- function(smd, se.smd, studlab,
                      ##
                      title = mdat$title, complab = mdat$complab,
                      outclab = mdat$outclab,
+                     #
                      label.e = mdat$label.e, label.c = mdat$label.c,
                      label.left = mdat$label.left,
                      label.right = mdat$label.right,
-                     ##
+                     col.label.left = mdat$col.label.left,
+                     col.label.right = mdat$col.label.right,
+                     #
                      subgroup = mdat$subgroup,
                      subgroup.name = mdat$subgroup.name,
                      print.subgroup.name = mdat$print.subgroup.name,
