@@ -37,6 +37,9 @@
 #'   meta-analysis should be conducted.
 #' @param random A logical indicating whether a random effects
 #'   meta-analysis should be conducted.
+#' @param method.common.ci A character string indicating which method
+#'   is used to calculate confidence interval and test statistic for
+#'   common effect estimate (see \code{\link{meta-package}}).
 #' @param method.random.ci A character string indicating which method
 #'   is used to calculate confidence interval and test statistic for
 #'   random effects estimate (see \code{\link{meta-package}}).
@@ -193,11 +196,15 @@ trimfill.meta <- function(x, left = NULL, ma.common = TRUE,
   chkclass(x, "meta")
   chksuitable(x, "Trim-and-fill method",
               c("metacum", "metainf", "metamerge", "netpairwise"))
-  ##
+  #
+  if (!is.null(x$weights.common) | !is.null(x$weights.random))
+    stop("Trim-and-fill method not implemented for user-specified weights.",
+         call. = FALSE)
+  #
   x <- updateversion(x)
   ##
   if (x$three.level)
-    stop("Trim-and-fill method not available for three-level model.",
+    stop("Trim-and-fill method not implemented for three-level model.",
          call. = FALSE)
   
   
@@ -540,6 +547,7 @@ trimfill.meta <- function(x, left = NULL, ma.common = TRUE,
     m <- metagen(-TE, seTE, studlab = studlab, level = x$level,
                  ##
                  level.ma = x$level.ma,
+                 method.common.ci = x$method.common.ci,
                  method.random.ci = x$method.random.ci,
                  adhoc.hakn.ci = x$adhoc.hakn.ci,
                  ##
@@ -558,6 +566,7 @@ trimfill.meta <- function(x, left = NULL, ma.common = TRUE,
     m <- metagen(TE, seTE, studlab = studlab, level = x$level,
                  ##
                  level.ma = x$level.ma,
+                 method.common.ci = x$method.common.ci,
                  method.random.ci = x$method.random.ci,
                  adhoc.hakn.ci = x$adhoc.hakn.ci,
                  ##
@@ -607,6 +616,7 @@ trimfill.meta <- function(x, left = NULL, ma.common = TRUE,
                    exclude = exclude, level = x$level,
                    ##
                    level.ma = x$level.ma,
+                   method.common.ci = x$method.common.ci,
                    method.random.ci = x$method.random.ci,
                    adhoc.hakn.ci = x$adhoc.hakn.ci,
                    ##
@@ -627,6 +637,7 @@ trimfill.meta <- function(x, left = NULL, ma.common = TRUE,
                    exclude = exclude, level = x$level,
                    ##
                    level.ma = x$level.ma,
+                   method.common.ci = x$method.common.ci,
                    method.random.ci = x$method.random.ci,
                    adhoc.hakn.ci = x$adhoc.hakn.ci,
                    ##
@@ -688,6 +699,7 @@ trimfill.meta <- function(x, left = NULL, ma.common = TRUE,
               TE.random = m$TE.random, seTE.random = m$seTE.random,
               statistic.random = m$statistic.random,
               pval.random = m$pval.random,
+              method.common.ci = x$method.common.ci,
               method.random.ci = x$method.random.ci,
               df.random = m$df.random,
               lower.random = m$lower.random, upper.random = m$upper.random,
@@ -819,6 +831,7 @@ trimfill.default <- function(x, seTE, left = NULL, ma.common = TRUE,
                              level = 0.95, level.ma = level,
                              common = FALSE, random = TRUE,
                              ##
+                             method.common.ci = gs("method.common.ci"),
                              method.random.ci = gs("method.random.ci"),
                              adhoc.hakn.ci = gs("adhoc.hakn.ci"),
                              ##
@@ -869,6 +882,7 @@ trimfill.default <- function(x, seTE, left = NULL, ma.common = TRUE,
                level = level, level.ma = level.ma,
                common = common, random = random,
                ##
+               method.common.ci = method.common.ci,
                method.random.ci = method.random.ci,
                adhoc.hakn.ci = adhoc.hakn.ci,
                ##
